DLindley: implements the [d-p-q-r]dlindley functions for the one-parameter discrete Lindley distribution.
DPLindley: implements the [d-p-q-r]dplindley functions for the discrete power Lindley distribution.
DWLindley: implements the [d-p-q-r]dwlindley functions for the weighted discrete Lindley distribution.
EXPLindley: implements the [d-h-p-q-r]explindley functions for the exponentiated Lindley distribution.
EXPPLindley: implements the [d-h-p-q-r]expplindley functions for the exponentiated power Lindley distribution.
EXTILindley: implements the [d-h-p-q-r]extilindley functions for the extended inverse Lindley distribution.
EXTLindley: implements the [d-h-p-q-r]extlindley functions for the extended Lindley distribution.
EXTPLindley: implements the [d-h-p-q-r]extplindley functions for the extended power Lindley distribution.
GAMLindley: implements the [d-h-p-q-r]extplindley functions for the Gamma Lindley Lindley distribution.
GENILindley: implements the [d-h-p-q-r]genilindley functions for the generalized inverse Lindley distribution.
GENLindley: implements the [d-h-p-q-r]genlindley functions for the generalized Lindley distribution.
ILindley: implements the [d-h-p-q-r]ilindley functions for the inverse Lindley distribution.
Lindley: implements the [d-h-p-q-r]lindley functions for one-parameter Lindley distributio.
LindleyE: implements the [d-h-p-q-r]lindleye functions for parameter Lindley exponential distribution.
MOLindley: implements the [d-h-p-q-r]molindley functions for the Marshall-Olkin extended Lindley distribution.
NWLindley: implements the [d-h-p-q-r]nwlindley functions for the new weighted Lindley distribution.
PLindley: implements the [d-h-p-q-r]plindley functions for the power Lindley distribution.
QLindley: implements the [d-h-p-q-r]qlindley functions for the quasi Lindley distribution.
randcensor: generate censored random samples, with a desired censoring rate, from any continuous lifetime distribution supported by R.
SLindley: implements the [d-h-p-q-r]slindley functions for the two-parameter Lindley distribution.
TLindley: implements the [d-h-p-q-r]tlindley functions for the transmuted Lindley distribution.
WLindley: implements the [d-h-p-q-r]wlindley functions for the weighted Lindley distribution.